@@ -1,21 +1,21 @@
-## Copyright (C) 1996 Auburn University.  All rights reserved.
+## Copyright (C) 1996, 2000, 2002, 2004, 2005, 2006, 2007
+##               Auburn University.  All rights reserved.
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
-## under the terms of the GNU General Public License as published by the
-## Free Software Foundation; either version 2, or (at your option) any
-## later version.
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but WITHOUT
-## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-## for more details.
+## Octave is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301 USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {[@var{y}, @var{t}] =} impulse (@var{sys}, @var{inp}, @var{tstop}, @var{n})
@@ -46,7 +46,7 @@
 ## @item t
 ## Times of the impulse response.
 ## @end table
-## @seealso{step, __stepimp__}
+## @seealso{step}
 ## @end deftypefn
 
 ## Author: Kai P. Mueller <mueller@ifr.ing.tu-bs.de>
@@ -56,11 +56,7 @@
 
 function [y, t] = impulse (sys, inp, tstop, n)
 
-  if ((nargin < 1) || (nargin > 4))
-    print_usage ();
-  endif
-
-  if (nargout > 2)
+  if (nargin < 1 || nargin > 4)
     print_usage ();
   endif
 
