@@ -1,11 +1,11 @@
-## Copyright (C) 1996, 1997 John W. Eaton
+## Copyright (C) 1996, 1997, 1998, 2000, 2005, 2006, 2007, 2008 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +13,8 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} logical (@var{arg})
@@ -38,8 +37,10 @@
 function y = logical (x)
 
   if (nargin == 1)
-    if (islogical (x) || isempty (x))
+    if (islogical (x))
       y = x;
+    elseif (isempty (x))
+      y = zeros (size (x), "logical");
     elseif (isnumeric (x))
       y = x != 0;
     else
@@ -50,3 +51,12 @@ function y = logical (x)
   endif
 
 endfunction
+
+%!assert (logical ([]), zeros ([0, 0], "logical"));
+%!assert (logical (zeros (2, 0)), zeros ([2, 0], "logical"));
+%!assert (logical (0), false);
+%!assert (logical (13), true);
+%!assert (logical (-13), true);
+%!assert (logical (int8 (13)), true);
+%!assert (logical (int8 (-13)), true);
+%!assert (logical ([-1, 0, 1, NaN, Inf]), [-1, 0, 1, NaN, Inf] != 0);
