@@ -1,11 +1,12 @@
-## Copyright (C) 2000, 2001, 2002 Teemu Ikonen
+## Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
+##               Teemu Ikonen
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +14,8 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## Undocumented internal function.
 
@@ -35,21 +35,22 @@ function h = __errplot__ (fstr, p, a1, a2, a3, a4, a5, a6)
 
   for i = 1:nplots
     ## Set the plot type based on linestyle.
-    if (fmt.linestyle == "~")
-      ifmt = "yerr";
-    elseif (fmt.linestyle == ">")
-      ifmt = "xerr";
-    elseif (fmt.linestyle == "~>")
-      ifmt = "xyerr";
-    elseif (fmt.linestyle == "#")
-      ifmt = "box";
-    elseif (fmt.linestyle == "#~")
-      ifmt = "boxy";
-    elseif (fmt.linestyle == "#~>")
-      ifmt = "boxxy";
-    else
-      print_usage ();
-    endif
+    switch (fmt.linestyle)
+      case "~"
+	ifmt = "yerr";
+      case ">"
+	ifmt = "xerr";
+      case "~>"
+	ifmt = "xyerr";
+      case "#"
+	ifmt = "box";
+      case "#~"
+	ifmt = "boxy";
+      case "#~>"
+	ifmt = "boxxy";
+      otherwise
+	print_usage ();
+    endswitch
 
     h = __line__ (p);
 
