@@ -1,11 +1,11 @@
-## Copyright (C) 2005 Paul Kienzle <pkienzle@users.sf.net>
+## Copyright (C) 2005, 2006, 2007 Paul Kienzle
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +13,8 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} fplot (@var{fn}, @var{limits})
@@ -38,8 +37,10 @@
 ## @seealso{plot}
 ## @end deftypefn
 
+## Author: Paul Kienzle <pkienzle@users.sf.net>
+
 function fplot (fn, limits, n, linespec)
-  if (nargin < 2 || nargin > 3)
+  if (nargin < 2 || nargin > 4)
     print_usage ();
   endif
 
@@ -72,10 +73,10 @@ function fplot (fn, limits, n, linespec)
 
   if (floor(n) != n)
     tol = n;
-    x0 = linspace (limits(1), limits(2), 3)';
+    x0 = linspace (limits(1), limits(2), 5)';
     y0 = feval (fn, x0);
     err0 = Inf;
-    n = 5;
+    n = 8;
     x = linspace (limits(1), limits(2), n)';
     y = feval (fn, x);
 
@@ -97,15 +98,16 @@ function fplot (fn, limits, n, linespec)
     y = feval (fn, x);
   endif
 
-  if (length (limits) > 2) 
-    axis (limits);
-  endif
-
   if (have_linespec)
     plot (x, y, linespec);
   else
     plot (x, y);
   endif
+
+  if (length (limits) > 2) 
+    axis (limits);
+  endif
+
   if (isvector(y))
     legend (nam);
   else
@@ -115,3 +117,9 @@ function fplot (fn, limits, n, linespec)
     legend (nams{:});
   endif
 endfunction
+
+%!demo
+%! fplot ("cos", [0, 2*pi])
+
+%!demo
+%! fplot ("[cos(x), sin(x)]", [0, 2*pi])
