@@ -1,5 +1,5 @@
 ## Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2002, 2003,
-##               2004, 2005, 2006, 2007 John W. Eaton
+##               2004, 2005, 2006, 2007, 2008 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -23,7 +23,8 @@
 ##
 ## With one vector input argument, plot a histogram of the values with
 ## 10 bins.  The range of the histogram bins is determined by the range
-## of the data.
+## of the data.  With one matrix input argument, plot a hystogram where
+## each bin contains a bar per input column.
 ##
 ## Given a second scalar argument, use that as the number of bins.
 ##
@@ -59,7 +60,7 @@ function [nn, xx] = hist (y, varargin)
     max_val = max (y(:));
     min_val = min (y(:));
   else
-    error ("hist: first argument must be a vector");
+    error ("hist: first argument must be real valued");
   endif
 
   iarg = 1;
@@ -69,14 +70,14 @@ function [nn, xx] = hist (y, varargin)
     x = x * (max_val - min_val) + ones(size(x)) * min_val;
   else
     ## nargin is either 2 or 3
-    x = varargin {iarg++};
+    x = varargin{iarg++};
     if (isscalar (x))
       n = x;
       if (n <= 0)
         error ("hist: number of bins must be positive");
       endif
       x = [0.5:n]'/n;
-      x = x * (max_val - min_val) + ones(size(x)) * min_val;
+      x = x * (max_val - min_val) + ones (size (x)) * min_val;
     elseif (isreal (x))
       if (isvector (x))
 	x = x(:);
@@ -91,11 +92,16 @@ function [nn, xx] = hist (y, varargin)
     endif
   endif
 
+  ## Avoid issues with integer types for x and y
+  x = double (x);
+  y = double (y);
+
   cutoff = (x(1:end-1,:) + x(2:end,:)) / 2;
   n = rows (x);
+  y_nc = columns (y);
   if (n < 30 && columns (x) == 1)
     ## The following algorithm works fastest for n less than about 30.
-    chist = zeros (n+1, columns (y));
+    chist = zeros (n+1, y_nc);
     for i = 1:n-1
       chist(i+1,:) = sum (y <= cutoff(i));
     endfor
@@ -104,18 +110,17 @@ function [nn, xx] = hist (y, varargin)
     ## The following algorithm works fastest for n greater than about 30.
     ## Put cutoff elements between boundaries, integrate over all
     ## elements, keep totals at boundaries.
-    [s, idx] = sort ([y; cutoff]);
+    [s, idx] = sort ([y; repmat(cutoff, 1, y_nc)]);
     len = rows (y);
     chist = cumsum (idx <= len);
-    t1 = zeros (1, columns (y));
-    t2 = reshape (chist(idx > len), size (cutoff));
-    t3 = chist(end,:) - sum (isnan (y));
-    chist = [t1; t2; t3];
+    chist = [(zeros (1, y_nc));
+	     (reshape (chist(idx > len), rows (cutoff), y_nc));
+	     (chist(end,:) - sum (isnan (y)))];
   endif
 
   freq = diff (chist);
 
-  if (nargin > 2 && !ischar (varargin{iarg}))
+  if (nargin > 2 && ! ischar (varargin{iarg}))
     ## Normalise the histogram.
     norm = varargin{iarg++};
     freq = freq / rows (y) * norm;
@@ -162,3 +167,5 @@ endfunction
 %!    assert( sum(hist([1:n], 29)), n);
 %!    assert( sum(hist([1:n], 30)), n);
 %!  endfor
+%!test
+%!  assert (size (hist(randn(750,240), 200)), [200,240]);
