@@ -1,11 +1,11 @@
-## Copyright (C) 1995, 1996, 1997  Kurt Hornik
+## Copyright (C) 1995, 1996, 1997, 2005, 2006, 2007 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +13,8 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} chi2rnd (@var{n}, @var{r}, @var{c})
@@ -52,7 +51,7 @@ function rnd = chi2rnd (n, r, c)
     elseif (isvector(r) && all (r > 0))
       sz = r(:)';
     else
-      error ("chi2rnd: r must be a postive integer or vector");
+      error ("chi2rnd: r must be a positive integer or vector");
     endif
 
     if (any (size (n) != 1)
@@ -69,7 +68,7 @@ function rnd = chi2rnd (n, r, c)
      if (find (!(n > 0) | !(n < Inf)))
        rnd = NaN * ones (sz);
      else
-       rnd = 2 * randg(n/2, sz)
+       rnd = 2 * randg(n/2, sz);
      endif
   else
     [retval, n, dummy] = common_size (n, ones (sz));
@@ -85,7 +84,7 @@ function rnd = chi2rnd (n, r, c)
 
     k = find ((n > 0) & (n < Inf));
     if (any (k))
-      rnd(k) = 2 * randg(n(k)/2, size(k))
+      rnd(k) = 2 * randg(n(k)/2, size(k));
     endif
   endif
 
