@@ -1,19 +1,21 @@
-## Copyright (C) 2000-2006 Paul Kienzle
+## Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
+##               Paul Kienzle
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
+## This file is part of Octave.
 ##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
+## Octave is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
+##
+## Octave is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this program; if not, write to the Free Software
-## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301  USA
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} speed (@var{f}, @var{init}, @var{max_n}, @var{f2}, @var{tol})
@@ -52,7 +54,7 @@
 ## expression @var{f} should produce a value @var{v} and expression @var{f2} 
 ## should produce a value @var{v2}, and these shall be compared using 
 ## @code{assert(@var{v},@var{v2},@var{tol})}. If @var{tol} is positive,
-## the tolerance is assumed to be absolutr. If @var{tol} is negative,
+## the tolerance is assumed to be absolute. If @var{tol} is negative,
 ## the tolerance is assumed to be relative. The default is @code{eps}.
 ##
 ## @item @var{order}
@@ -60,7 +62,7 @@
 ## is a structure with fields @code{a} and @code{p}.
 ##
 ## @item @var{n}
-## The values @var{n} for which the expression was calculated and the
+## The values @var{n} for which the expression was calculated and
 ## the execution time was greater than zero.
 ##
 ## @item @var{T_f}
@@ -128,7 +130,7 @@
 ##         "v2=xcorr_orig(x,n)", -100*eps)
 ## @end example
 ##
-## Assuming one of the two versions is in @var{xcorr_orig}, this would
+## Assuming one of the two versions is in @var{xcorr_orig}, this
 ## would compare their speed and their output values.  Note that the
 ## FFT version is not exact, so we specify an acceptable tolerance on
 ## the comparison @code{100*eps}, and the errors should be computed
