@@ -1524,7 +1524,7 @@ DEFUN (isinteger, args, ,
 @deftypefn {Built-in Function} {} isinteger (@var{x})\n\
 Return true if @var{x} is an integer object (int8, uint8, int16, etc.).\n\
 Note that @code{isinteger (14)} is false because numeric constants in\n\
-are double precision floating point values.\n\
+Octave are double precision floating point values.\n\
 @seealso{isreal, isnumeric, class, isa}\n\
 @end deftypefn")
 {
@@ -2670,7 +2670,7 @@ result is @var{m}-by-@var{m}.  If @var{m} is a vector, then the\n\
 dimensions of the result are given by the elements of @var{m}.\n\
 If both @var{m} and @var{n} are scalars, then the dimensions of\n\
 the result are @var{m}-by-@var{n}.\n\
-@seealso{reshape}\n\
+@seealso{reshape, postpad}\n\
 @end deftypefn")
 {
   octave_value retval;
