@@ -1,13 +1,14 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
+              2002, 2003, 2004, 2005, 2006, 2007 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -1063,6 +1063,18 @@ raw_help_from_file (const std::string& nm, std::string& h,
 
   if (h.length () > 0)
     retval = true;
+  else if (! symbol_found)
+    {
+      file = contents_file_in_path (nm);
+      
+      if (! file.empty ())
+	{
+	  h = get_help_from_file (file, symbol_found);
+
+	  if (h.length () > 0)
+	    retval = true;
+	}
+    }
 
   return retval;
 }
@@ -1295,7 +1307,7 @@ the @code{-q} option suppresses this behaviour.\n\
   return retval;
 }
 
-static std::string
+std::string
 do_which (const std::string& name)
 {
   std::string retval;
@@ -1744,9 +1756,9 @@ DEFCMD (lookfor, args, nargout,
 @deffnx {Function} {[@var{fun}, @var{helpstring}] = } lookfor (@var{str})\n\
 @deffnx {Function} {[@var{fun}, @var{helpstring}] = } lookfor ('-all', @var{str})\n\
 Search for the string @var{str} in all of the functions found in the\n\
-function search path.  By default @code{lookfor} searchs for @var{str}\n\
+function search path.  By default @code{lookfor} searches for @var{str}\n\
 in the first sentence of the help string of each function found. The entire\n\
-help string of each function found in the path can be search if\n\
+help string of each function found in the path can be searched if\n\
 the '-all' argument is supplied. All searches are case insensitive.\n\
 \n\
 Called with no output arguments, @code{lookfor} prints the list of matching\n\
@@ -1769,7 +1781,7 @@ to find related functions that are not part of Octave.\n\
 
   if (nargin != 1 && nargin != 2)
     {
-      usage ("lookfor");
+      print_usage ();
       return retval;
     }
 
@@ -1982,7 +1994,10 @@ to find related functions that are not part of Octave.\n\
 
 		      std::string file_name = load_path::find_fcn (name);
 		      
-		      std::string dir = dirs[i] + file_ops::dir_sep_str;
+		      std::string dir = dirs[i];
+
+		      if (! file_ops::is_dir_sep (dir[dir.length()-1]))
+			dir += file_ops::dir_sep_str;
 
 		      if (file_name == dir + name + ".oct"
 			  || file_name == dir + name + ".m")
@@ -2130,7 +2145,7 @@ DEFUN (info_program, args, nargout,
 @deftypefn {Built-in Function} {@var{val} =} info_program ()\n\
 @deftypefnx {Built-in Function} {@var{old_val} =} info_program (@var{new_val})\n\
 Query or set the internal variable that specifies the name of the\n\
-info program to run.  The default initial value is\n\
+info program to run.  The default value is\n\
 @code{\"@var{octave-home}/libexec/octave/@var{version}/exec/@var{arch}/info\"}\n\
 in which @var{octave-home} is the directory where all of Octave is\n\
 installed, @var{version} is the Octave version number, and @var{arch}\n\
@@ -2161,7 +2176,7 @@ DEFUN (suppress_verbose_help_message, args, nargout,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {@var{val} =} suppress_verbose_help_message ()\n\
 @deftypefnx {Built-in Function} {@var{old_val} =} suppress_verbose_help_message (@var{new_val})\n\
-Query or set the internal vaiable that controls whether Octave\n\
+Query or set the internal variable that controls whether Octave\n\
 will add additional help information to the end of the output from\n\
 the @code{help} command and usage messages for built-in commands.\n\
 @end deftypefn")
