@@ -29,6 +29,7 @@ along with Octave; see the file COPYING.  If not, see
 #include <string>
 
 #include "str-vec.h"
+#include "ls-ascii-helper.h"
 
 // Flag for cell elements
 #define CELL_ELT_TAG "<cell-element>"
@@ -99,12 +100,12 @@ extract_keyword (std::istream& is, const char *keyword, T& value,
 		; // Skip whitespace and the colon.
 
 	      is.putback (c);
-	      if (c != '\n')
+	      if (c != '\n' && c != '\r')
 		is >> value;
 	      if (is)
 		status = true;
-	      while (is.get (c) && c != '\n')
-		; // Skip to beginning of next line;
+	      // Skip to beginning of next line;
+	      skip_until_newline (is, false);
 	      break;
 	    }
 	  else if (next_only)
@@ -161,12 +162,12 @@ extract_keyword (std::istream& is, const string_vector& keywords,
 		    ; // Skip whitespace and the colon.
 
 		  is.putback (c);
-		  if (c != '\n')
+		  if (c != '\n' && c != '\r')
 		    is >> value;
 		  if (is)
 		    status = true;
-		  while (is.get (c) && c != '\n')
-		    ; // Skip to beginning of next line;
+		  // Skip to beginning of next line;
+		  skip_until_newline (is, false);
 		  return status;
 		}
 	    }
