@@ -1,13 +1,14 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1996, 1997, 1998, 2000, 2001, 2002, 2003, 2004, 2005,
+              2006, 2007 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -48,6 +48,7 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include "ov-base-mat.cc"
 #include "ov-scalar.h"
 #include "ov-re-mat.h"
+#include "ov-re-sparse.h"
 #include "ov-type-conv.h"
 #include "pr-output.h"
 #include "variables.h"
@@ -255,7 +256,7 @@ octave_matrix::convert_to_str_internal (bool, bool, char type) const
 }
 
 bool 
-octave_matrix::save_ascii (std::ostream& os, bool& infnan_warned)
+octave_matrix::save_ascii (std::ostream& os)
 {
   dim_vector d = dims ();
 
@@ -263,12 +264,6 @@ octave_matrix::save_ascii (std::ostream& os, bool& infnan_warned)
     {
       NDArray tmp = array_value ();
 
-      if (! infnan_warned && tmp.any_element_is_inf_or_nan ())
-	{
-	  warning ("save: Inf or NaN values may not be reloadable");
-	  infnan_warned = true;
-	}
-
       os << "# ndims: " << d.length () << "\n";
 
       for (int i=0; i < d.length (); i++)
@@ -659,7 +654,25 @@ DEFUN (double, args, ,
 Convert @var{x} to double precision type.\n\
 @end deftypefn")
 {
-  OCTAVE_TYPE_CONV_BODY3 (double, octave_matrix, octave_scalar);
+  // The OCTAVE_TYPE_CONV_BODY3 macro declares retval, so they go
+  // inside their own scopes, and we don't declare retval here to
+  // avoid a shadowed declaration warning.
+
+  if (args.length () == 1)
+    {
+      if (args(0).is_sparse_type ())
+	{
+	  OCTAVE_TYPE_CONV_BODY3 (double, octave_sparse_matrix, octave_scalar);
+	}
+      else
+	{
+	  OCTAVE_TYPE_CONV_BODY3 (double, octave_matrix, octave_scalar);
+	}
+    }
+  else
+    print_usage ();
+
+  return octave_value ();
 }
 
 /*
